@@ -100,17 +100,17 @@ class PodOperatorHookProtocol(Protocol):
         """Read pod object from kubernetes API."""
 
     def get_namespace(self) -> str | None:
-        """Returns the namespace that defined in the connection."""
+        """Return the namespace that defined in the connection."""
 
     def get_xcom_sidecar_container_image(self) -> str | None:
-        """Returns the xcom sidecar image that defined in the connection."""
+        """Return the xcom sidecar image that defined in the connection."""
 
     def get_xcom_sidecar_container_resources(self) -> str | None:
-        """Returns the xcom sidecar resources that defined in the connection."""
+        """Return the xcom sidecar resources that defined in the connection."""
 
 
 def get_container_status(pod: V1Pod, container_name: str) -> V1ContainerStatus | None:
-    """Retrieves container status."""
+    """Retrieve container status."""
     container_statuses = pod.status.container_statuses if pod and pod.status else None
     if container_statuses:
         # In general the variable container_statuses can store multiple items matching different containers.
@@ -123,7 +123,7 @@ def get_container_status(pod: V1Pod, container_name: str) -> V1ContainerStatus |
 
 def container_is_running(pod: V1Pod, container_name: str) -> bool:
     """
-    Examines V1Pod ``pod`` to determine whether ``container_name`` is running.
+    Examine V1Pod ``pod`` to determine whether ``container_name`` is running.
 
     If that container is present and running, returns True.  Returns False otherwise.
     """
@@ -135,7 +135,7 @@ def container_is_running(pod: V1Pod, container_name: str) -> bool:
 
 def container_is_completed(pod: V1Pod, container_name: str) -> bool:
     """
-    Examines V1Pod ``pod`` to determine whether ``container_name`` is completed.
+    Examine V1Pod ``pod`` to determine whether ``container_name`` is completed.
 
     If that container is present and completed, returns True.  Returns False otherwise.
     """
@@ -147,7 +147,7 @@ def container_is_completed(pod: V1Pod, container_name: str) -> bool:
 
 def container_is_succeeded(pod: V1Pod, container_name: str) -> bool:
     """
-    Examines V1Pod ``pod`` to determine whether ``container_name`` is completed and succeeded.
+    Examine V1Pod ``pod`` to determine whether ``container_name`` is completed and succeeded.
 
     If that container is present and completed and succeeded, returns True.  Returns False otherwise.
     """
@@ -162,7 +162,7 @@ def container_is_succeeded(pod: V1Pod, container_name: str) -> bool:
 
 def container_is_terminated(pod: V1Pod, container_name: str) -> bool:
     """
-    Examines V1Pod ``pod`` to determine whether ``container_name`` is terminated.
+    Examine V1Pod ``pod`` to determine whether ``container_name`` is terminated.
 
     If that container is present and terminated, returns True.  Returns False otherwise.
     """
@@ -219,7 +219,7 @@ class PodLogsConsumer:
         self.read_pod_cache_timeout = read_pod_cache_timeout
 
     def __iter__(self) -> Generator[bytes, None, None]:
-        r"""The generator yields log items divided by the '\n' symbol."""
+        r"""Yield log items divided by the '\n' symbol."""
         incomplete_log_item: list[bytes] = []
         if self.logs_available():
             for data_chunk in self.response.stream(amt=None, decode_content=True):
@@ -270,7 +270,7 @@ class PodLogsConsumer:
 
 @dataclass
 class PodLoggingStatus:
-    """Used for returning the status of the pod and last log time when exiting from `fetch_container_logs`."""
+    """Return the status of the pod and last log time when exiting from `fetch_container_logs`."""
 
     running: bool
     last_log_time: DateTime | None
@@ -285,7 +285,7 @@ class PodManager(LoggingMixin):
         progress_callback: Callable[[str], None] | None = None,
     ):
         """
-        Creates the launcher.
+        Create the launcher.
 
         :param kube_client: kubernetes client
         :param progress_callback: Callback function invoked when fetching container log.
@@ -296,7 +296,7 @@ class PodManager(LoggingMixin):
         self._watch = watch.Watch()
 
     def run_pod_async(self, pod: V1Pod, **kwargs) -> V1Pod:
-        """Runs POD asynchronously."""
+        """Run POD asynchronously."""
         sanitized_pod = self._client.api_client.sanitize_for_serialization(pod)
         json_pod = json.dumps(sanitized_pod, indent=2)
 
@@ -314,7 +314,7 @@ class PodManager(LoggingMixin):
         return resp
 
     def delete_pod(self, pod: V1Pod) -> None:
-        """Deletes POD."""
+        """Delete POD."""
         try:
             self._client.delete_namespaced_pod(
                 pod.metadata.name, pod.metadata.namespace, body=client.V1DeleteOptions()
@@ -331,12 +331,12 @@ class PodManager(LoggingMixin):
         retry=tenacity.retry_if_exception(should_retry_start_pod),
     )
     def create_pod(self, pod: V1Pod) -> V1Pod:
-        """Launches the pod asynchronously."""
+        """Launch the pod asynchronously."""
         return self.run_pod_async(pod)
 
     def await_pod_start(self, pod: V1Pod, startup_timeout: int = 120) -> None:
         """
-        Waits for the pod to reach phase other than ``Pending``.
+        Wait for the pod to reach phase other than ``Pending``.
 
         :param pod:
         :param startup_timeout: Timeout (in seconds) for startup of the pod
@@ -376,7 +376,7 @@ class PodManager(LoggingMixin):
         post_termination_timeout: int = 120,
     ) -> PodLoggingStatus:
         """
-        Follows the logs of container and streams to airflow logging.
+        Follow the logs of container and stream to airflow logging.
 
         Returns when container exits.
 
@@ -399,7 +399,7 @@ class PodManager(LoggingMixin):
             logs: PodLogsConsumer | None,
         ) -> tuple[DateTime | None, PodLogsConsumer | None]:
             """
-            Tries to follow container logs until container completes.
+            Try to follow container logs until container completes.
 
             For a long-running container, sometimes the log read may be interrupted
             Such errors of this kind are suppressed.
@@ -549,7 +549,7 @@ class PodManager(LoggingMixin):
 
     def await_container_completion(self, pod: V1Pod, container_name: str) -> None:
         """
-        Waits for the given container in the given pod to be completed.
+        Wait for the given container in the given pod to be completed.
 
         :param pod: pod spec that will be monitored
         :param container_name: name of the container within the pod to monitor
@@ -566,7 +566,7 @@ class PodManager(LoggingMixin):
         self, pod: V1Pod, istio_enabled: bool = False, container_name: str = "base"
     ) -> V1Pod:
         """
-        Monitors a pod and returns the final state.
+        Monitor a pod and return the final state.
 
         :param istio_enabled: whether istio is enabled in the namespace
         :param pod: pod spec that will be monitored
@@ -600,12 +600,12 @@ class PodManager(LoggingMixin):
         return last_log_time, message
 
     def container_is_running(self, pod: V1Pod, container_name: str) -> bool:
-        """Reads pod and checks if container is running."""
+        """Read pod and checks if container is running."""
         remote_pod = self.read_pod(pod)
         return container_is_running(pod=remote_pod, container_name=container_name)
 
     def container_is_terminated(self, pod: V1Pod, container_name: str) -> bool:
-        """Reads pod and checks if container is terminated."""
+        """Read pod and checks if container is terminated."""
         remote_pod = self.read_pod(pod)
         return container_is_terminated(pod=remote_pod, container_name=container_name)
 
@@ -620,7 +620,7 @@ class PodManager(LoggingMixin):
         follow=True,
         post_termination_timeout: int = 120,
     ) -> PodLogsConsumer:
-        """Reads log from the POD."""
+        """Read log from the POD."""
         additional_kwargs = {}
         if since_seconds:
             additional_kwargs["since_seconds"] = since_seconds
@@ -662,7 +662,7 @@ class PodManager(LoggingMixin):
 
     @tenacity.retry(stop=tenacity.stop_after_attempt(3), wait=tenacity.wait_exponential(), reraise=True)
     def read_pod_events(self, pod: V1Pod) -> CoreV1EventList:
-        """Reads events from the POD."""
+        """Read events from the POD."""
         try:
             return self._client.list_namespaced_event(
                 namespace=pod.metadata.namespace, field_selector=f"involvedObject.name={pod.metadata.name}"
@@ -689,7 +689,7 @@ class PodManager(LoggingMixin):
             time.sleep(1)
 
     def extract_xcom(self, pod: V1Pod) -> str:
-        """Retrieves XCom value and kills xcom sidecar container."""
+        """Retrieve XCom value and kill xcom sidecar container."""
         try:
             result = self.extract_xcom_json(pod)
             return result
@@ -702,7 +702,7 @@ class PodManager(LoggingMixin):
         reraise=True,
     )
     def extract_xcom_json(self, pod: V1Pod) -> str:
-        """Retrieves XCom value and also checks if xcom json is valid."""
+        """Retrieve XCom value and also check if xcom json is valid."""
         with closing(
             kubernetes_stream(
                 self._client.connect_get_namespaced_pod_exec,
@@ -736,7 +736,7 @@ class PodManager(LoggingMixin):
         reraise=True,
     )
     def extract_xcom_kill(self, pod: V1Pod):
-        """Kills xcom sidecar container."""
+        """Kill xcom sidecar container."""
         with closing(
             kubernetes_stream(
                 self._client.connect_get_namespaced_pod_exec,
